import { AccessFlags, CollectionFormat, DecoratorInfo, SdkBuiltInKinds, SerializationOptions, UsageFlags } from "@azure-tools/typespec-client-generator-core";
import { DateTimeKnownEncoding, DurationKnownEncoding } from "@typespec/compiler";
import { InputParameter } from "./input-parameter.js";
import { InputServiceMethod } from "./input-service-method.js";
/**
 * The input client type for the CSharp emitter.
 * @beta
 */
export interface InputClient extends DecoratedType {
    kind: "client";
    name: string;
    namespace: string;
    doc?: string;
    summary?: string;
    parameters?: InputParameter[];
    methods: InputServiceMethod[];
    apiVersions: string[];
    crossLanguageDefinitionId: string;
    parent?: InputClient;
    children?: InputClient[];
}
interface DecoratedType {
    decorators?: DecoratorInfo[];
}
interface InputTypeBase extends DecoratedType {
    kind: string;
    summary?: string;
    doc?: string;
    deprecation?: string;
}
export type InputType = InputPrimitiveType | InputDateTimeType | InputDurationType | InputLiteralType | InputUnionType | InputModelType | InputEnumType | InputEnumValueType | InputArrayType | InputDictionaryType | InputNullableType;
export interface InputPrimitiveType extends InputTypeBase {
    kind: SdkBuiltInKinds;
    name: string;
    encode?: string;
    crossLanguageDefinitionId: string;
    baseType?: InputPrimitiveType;
}
export interface InputLiteralType extends InputTypeBase {
    kind: "constant";
    name: string;
    access?: AccessFlags;
    usage: UsageFlags;
    namespace: string;
    valueType: InputPrimitiveType;
    value: string | number | boolean | null;
}
export declare function isInputLiteralType(type: InputType): type is InputLiteralType;
export type InputDateTimeType = InputUtcDateTimeType | InputOffsetDateTimeType;
interface InputDateTimeTypeBase extends InputTypeBase {
    name: string;
    encode: DateTimeKnownEncoding;
    wireType: InputPrimitiveType;
    crossLanguageDefinitionId: string;
    baseType?: InputDateTimeType;
}
export interface InputUtcDateTimeType extends InputDateTimeTypeBase {
    kind: "utcDateTime";
}
export interface InputOffsetDateTimeType extends InputDateTimeTypeBase {
    kind: "offsetDateTime";
}
export interface InputDurationType extends InputTypeBase {
    kind: "duration";
    name: string;
    encode: DurationKnownEncoding;
    wireType: InputPrimitiveType;
    crossLanguageDefinitionId: string;
    baseType?: InputDurationType;
}
export interface InputUnionType extends InputTypeBase {
    kind: "union";
    name: string;
    variantTypes: InputType[];
    namespace: string;
}
export declare function isInputUnionType(type: InputType): type is InputUnionType;
/**
 * The input model type for the CSharp emitter.
 * @beta
 */
export interface InputModelType extends InputTypeBase {
    kind: "model";
    properties: InputProperty[];
    name: string;
    crossLanguageDefinitionId: string;
    access?: AccessFlags;
    usage: UsageFlags;
    namespace: string;
    additionalProperties?: InputType;
    discriminatorValue?: string;
    discriminatedSubtypes?: Record<string, InputModelType>;
    discriminatorProperty?: InputProperty;
    baseModel?: InputModelType;
    serializationOptions: SerializationOptions;
}
export interface InputPropertyTypeBase extends DecoratedType {
    type: InputType;
    name: string;
    doc?: string;
    summary?: string;
    optional: boolean;
    crossLanguageDefinitionId: string;
    readOnly: boolean;
    access?: AccessFlags;
}
export interface InputModelProperty extends InputPropertyTypeBase {
    kind: "property";
    discriminator: boolean;
    serializedName: string;
    serializationOptions: SerializationOptions;
    flatten: boolean;
}
export type InputProperty = InputModelProperty | InputHttpParameter;
export type InputHttpParameter = InputQueryParameter | InputPathParameter | InputHeaderParameter | InputBodyParameter;
export interface InputQueryParameter extends InputPropertyTypeBase {
    kind: "query";
    collectionFormat?: CollectionFormat;
    serializedName: string;
    correspondingMethodParams: InputProperty[];
    explode: boolean;
}
export interface InputPathParameter extends InputPropertyTypeBase {
    kind: "path";
    explode: boolean;
    style: "simple" | "label" | "matrix" | "fragment" | "path";
    allowReserved: boolean;
    serializedName: string;
    correspondingMethodParams: InputProperty[];
}
export interface InputHeaderParameter extends InputPropertyTypeBase {
    kind: "header";
    collectionFormat?: CollectionFormat;
    serializedName: string;
    correspondingMethodParams: InputProperty[];
}
export interface InputBodyParameter extends InputPropertyTypeBase {
    kind: "body";
    serializedName: string;
    contentTypes: string[];
    defaultContentType: string;
    correspondingMethodParams: InputProperty[];
}
export interface InputEnumType extends InputTypeBase {
    kind: "enum";
    name: string;
    crossLanguageDefinitionId: string;
    valueType: InputPrimitiveType;
    values: InputEnumValueType[];
    isFixed: boolean;
    isFlags: boolean;
    usage: UsageFlags;
    access?: AccessFlags;
    namespace: string;
}
export interface InputEnumValueType extends InputTypeBase {
    kind: "enumvalue";
    name: string;
    value: string | number;
    enumType: InputEnumType;
    valueType: InputPrimitiveType;
}
export interface InputNullableType extends InputTypeBase {
    kind: "nullable";
    type: InputType;
    namespace: string;
}
export declare function isInputEnumType(type: InputType): type is InputEnumType;
export interface InputArrayType extends InputTypeBase {
    kind: "array";
    name: string;
    valueType: InputType;
    crossLanguageDefinitionId: string;
}
export declare function isInputArrayType(type: InputType): type is InputArrayType;
export interface InputDictionaryType extends InputTypeBase {
    kind: "dict";
    keyType: InputType;
    valueType: InputType;
}
export declare function isInputDictionaryType(type: InputType): type is InputDictionaryType;
export {};
//# sourceMappingURL=input-type.d.ts.map